@@ -13,13 +13,18 @@ describe 'octavia::controller' do
 
     context 'configured with specific parameters' do
       let :params do
-        { :amp_flavor_id           => '42',
-          :amp_image_tag           => 'amphorae1',
-          :amp_secgroup_list       => ['lb-mgmt-sec-grp'],
-          :amp_boot_network_list   => ['lbnet1', 'lbnet2'],
-          :loadbalancer_topology   => 'SINGLE',
-          :amp_ssh_key_name        => 'custom-amphora-key',
-          :controller_ip_port_list => '1.2.3.4:5555,4.3.2.1:5555',
+        { :amp_flavor_id              => '42',
+          :amp_image_tag              => 'amphorae1',
+          :amp_secgroup_list          => ['lb-mgmt-sec-grp'],
+          :amp_boot_network_list      => ['lbnet1', 'lbnet2'],
+          :loadbalancer_topology      => 'SINGLE',
+          :amp_ssh_key_name           => 'custom-amphora-key',
+          :controller_ip_port_list    => '1.2.3.4:5555,4.3.2.1:5555',
+          :connection_max_retries     => 240,
+          :connection_retry_interval  => 10,
+          :connection_logging         => false,
+          :build_active_retries       => 5,
+          :port_detach_timeout        => 15
         }
       end
 
@@ -30,6 +35,11 @@ describe 'octavia::controller' do
       it { is_expected.to contain_octavia_config('controller_worker/loadbalancer_topology').with_value('SINGLE') }
       it { is_expected.to contain_octavia_config('controller_worker/amp_ssh_key_name').with_value('custom-amphora-key') }
       it { is_expected.to contain_octavia_config('health_manager/controller_ip_port_list').with_value('1.2.3.4:5555,4.3.2.1:5555') }
+      it { is_expected.to contain_octavia_config('haproxy_amphora/connection_max_retries').with_value(240) }
+      it { is_expected.to contain_octavia_config('haproxy_amphora/connection_retry_interval').with_value(10) }
+      it { is_expected.to contain_octavia_config('haproxy_amphora/connection_logging').with_value(false) }
+      it { is_expected.to contain_octavia_config('haproxy_amphora/build_active_retries').with_value(5) }
+      it { is_expected.to contain_octavia_config('networking/port_detach_timeout').with_value(15) }
     end
 
     it 'configures worker parameters' do
@@ -42,6 +52,11 @@ describe 'octavia::controller' do
       is_expected.to contain_octavia_config('haproxy_amphora/timeout_member_connect').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_octavia_config('haproxy_amphora/timeout_member_data').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_octavia_config('haproxy_amphora/timeout_tcp_inspect').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_octavia_config('haproxy_amphora/connection_max_retries').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_octavia_config('haproxy_amphora/connection_retry_interval').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_octavia_config('haproxy_amphora/connection_logging').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_octavia_config('haproxy_amphora/build_active_retries').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_octavia_config('networking/port_detach_timeout').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with ssh key access disabled' do
